"""
SatNOGS Decoders package initialization
"""
from __future__ import absolute_import, division, print_function

from ._version import get_versions

__version__ = get_versions()['version']

del get_versions



# This is a generated file! Please edit source .ksy file and use kaitai-struct-compiler to rebuild

from pkg_resources import parse_version
import kaitaistruct
from kaitaistruct import KaitaiStruct, KaitaiStream, BytesIO


if parse_version(kaitaistruct.__version__) < parse_version('0.9'):
    raise Exception("Incompatible Kaitai Struct Python API: 0.9 or later is required, but you have %s" % (kaitaistruct.__version__))

class Ledsat(KaitaiStruct):
    """:field priority: csp_header.priority
    :field source: csp_header.source
    :field destination: csp_header.destination
    :field destination_port: csp_header.destination_port
    :field source_port: csp_header.source_port
    :field reserved: csp_header.reserved
    :field hmac: csp_header.hmac
    :field xtea: csp_header.xtea
    :field rdp: csp_header.rdp
    :field crc: csp_header.crc
    :field telemetry_identifier: csp_data.payload.telemetry_identifier
    :field unix_ts_ms: csp_data.payload.unix_ts_ms
    :field unix_ts_s: csp_data.payload.unix_ts_s
    :field tlm_process_time: csp_data.payload.tlm_process_time
    :field panel_x_voltage: csp_data.payload.panel_x_voltage
    :field panel_y_voltage: csp_data.payload.panel_y_voltage
    :field panel_z_voltage: csp_data.payload.panel_z_voltage
    :field panel_x_current: csp_data.payload.panel_x_current
    :field panel_y_current: csp_data.payload.panel_y_current
    :field panel_z_current: csp_data.payload.panel_z_current
    :field eps_boot_cause: csp_data.payload.eps_boot_cause
    :field eps_battery_mode: csp_data.payload.eps_battery_mode
    :field mppt_x_temp: csp_data.payload.mppt_x_temp
    :field mppt_y_temp: csp_data.payload.mppt_y_temp
    :field eps_board_temp: csp_data.payload.eps_board_temp
    :field battery_pack1_temp: csp_data.payload.battery_pack1_temp
    :field battery_pack2_temp: csp_data.payload.battery_pack2_temp
    :field battery_pack3_temp: csp_data.payload.battery_pack3_temp
    :field solar_current: csp_data.payload.solar_current
    :field system_current: csp_data.payload.system_current
    :field battery_voltage: csp_data.payload.battery_voltage
    :field gps_current: csp_data.payload.gps_current
    :field eps_boot_count: csp_data.payload.eps_boot_count
    :field trx_pa_temp: csp_data.payload.trx_pa_temp
    :field trx_total_tx_cnt: csp_data.payload.trx_total_tx_cnt
    :field trx_total_rx_cnt: csp_data.payload.trx_total_rx_cnt
    :field last_rssi: csp_data.payload.last_rssi
    :field radio_boot_cnt: csp_data.payload.radio_boot_cnt
    :field obc_temp_1: csp_data.payload.obc_temp_1
    :field obc_temp_2: csp_data.payload.obc_temp_2
    :field gyro_x: csp_data.payload.gyro_x
    :field gyro_y: csp_data.payload.gyro_y
    :field gyro_z: csp_data.payload.gyro_z
    :field mag_x: csp_data.payload.mag_x
    :field mag_y: csp_data.payload.mag_y
    :field mag_z: csp_data.payload.mag_z
    :field px_solar_panel_temp: csp_data.payload.px_solar_panel_temp
    :field py_solar_panel_temp: csp_data.payload.py_solar_panel_temp
    :field nx_solar_panel_temp: csp_data.payload.nx_solar_panel_temp
    :field ny_solar_panel_temp: csp_data.payload.ny_solar_panel_temp
    :field pz_solar_panel_temp: csp_data.payload.pz_solar_panel_temp
    :field nz_solar_panel_temp: csp_data.payload.nz_solar_panel_temp
    :field px_sun_sensor_coarse: csp_data.payload.px_sun_sensor_coarse
    :field py_sun_sensor_coarse: csp_data.payload.py_sun_sensor_coarse
    :field pz_sun_sensor_coarse: csp_data.payload.pz_sun_sensor_coarse
    :field nx_sun_sensor_coarse: csp_data.payload.nx_sun_sensor_coarse
    :field ny_sun_sensor_coarse: csp_data.payload.ny_sun_sensor_coarse
    :field nz_sun_sensor_coarse: csp_data.payload.nz_sun_sensor_coarse
    :field eps_outputs_status: csp_data.payload.eps_outputs_status
    :field obc_boot_counter: csp_data.payload.obc_boot_counter
    :field leds_status: csp_data.payload.leds_status
    :field gps_status: csp_data.payload.gps_status
    :field gps_fix_time: csp_data.payload.gps_fix_time
    :field gps_lat: csp_data.payload.gps_lat
    :field gps_lon: csp_data.payload.gps_lon
    :field gps_alt: csp_data.payload.gps_alt
    :field software_status: csp_data.payload.software_status
    :field ext_gyro_x: csp_data.payload.ext_gyro_x
    :field ext_gyro_y: csp_data.payload.ext_gyro_y
    :field ext_gyro_z: csp_data.payload.ext_gyro_z
    :field ext_mag_x: csp_data.payload.ext_mag_x
    :field ext_mag_y: csp_data.payload.ext_mag_y
    :field ext_mag_z: csp_data.payload.ext_mag_z
    :field framelength: framelength
    """
    def __init__(self, _io, _parent=None, _root=None):
        self._io = _io
        self._parent = _parent
        self._root = _root if _root else self
        self._read()

    def _read(self):
        self.csp_header = Ledsat.CspHeaderT(self._io, self, self._root)
        self.csp_data = Ledsat.CspDataT(self._io, self, self._root)

    class CspHeaderT(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.raw_csp_header = self._io.read_u4be()

        @property
        def source(self):
            if hasattr(self, '_m_source'):
                return self._m_source if hasattr(self, '_m_source') else None

            self._m_source = ((self.raw_csp_header >> 25) & 31)
            return self._m_source if hasattr(self, '_m_source') else None

        @property
        def source_port(self):
            if hasattr(self, '_m_source_port'):
                return self._m_source_port if hasattr(self, '_m_source_port') else None

            self._m_source_port = ((self.raw_csp_header >> 8) & 63)
            return self._m_source_port if hasattr(self, '_m_source_port') else None

        @property
        def destination_port(self):
            if hasattr(self, '_m_destination_port'):
                return self._m_destination_port if hasattr(self, '_m_destination_port') else None

            self._m_destination_port = ((self.raw_csp_header >> 14) & 63)
            return self._m_destination_port if hasattr(self, '_m_destination_port') else None

        @property
        def rdp(self):
            if hasattr(self, '_m_rdp'):
                return self._m_rdp if hasattr(self, '_m_rdp') else None

            self._m_rdp = ((self.raw_csp_header & 2) >> 1)
            return self._m_rdp if hasattr(self, '_m_rdp') else None

        @property
        def destination(self):
            if hasattr(self, '_m_destination'):
                return self._m_destination if hasattr(self, '_m_destination') else None

            self._m_destination = ((self.raw_csp_header >> 20) & 31)
            return self._m_destination if hasattr(self, '_m_destination') else None

        @property
        def priority(self):
            if hasattr(self, '_m_priority'):
                return self._m_priority if hasattr(self, '_m_priority') else None

            self._m_priority = (self.raw_csp_header >> 30)
            return self._m_priority if hasattr(self, '_m_priority') else None

        @property
        def reserved(self):
            if hasattr(self, '_m_reserved'):
                return self._m_reserved if hasattr(self, '_m_reserved') else None

            self._m_reserved = ((self.raw_csp_header >> 4) & 15)
            return self._m_reserved if hasattr(self, '_m_reserved') else None

        @property
        def xtea(self):
            if hasattr(self, '_m_xtea'):
                return self._m_xtea if hasattr(self, '_m_xtea') else None

            self._m_xtea = ((self.raw_csp_header & 4) >> 2)
            return self._m_xtea if hasattr(self, '_m_xtea') else None

        @property
        def hmac(self):
            if hasattr(self, '_m_hmac'):
                return self._m_hmac if hasattr(self, '_m_hmac') else None

            self._m_hmac = ((self.raw_csp_header & 8) >> 3)
            return self._m_hmac if hasattr(self, '_m_hmac') else None

        @property
        def crc(self):
            if hasattr(self, '_m_crc'):
                return self._m_crc if hasattr(self, '_m_crc') else None

            self._m_crc = (self.raw_csp_header & 1)
            return self._m_crc if hasattr(self, '_m_crc') else None


    class CspDataT(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            _on = self._parent.csp_header.destination_port
            if _on == 8:
                self.payload = Ledsat.LedsatTlmT(self._io, self, self._root)


    class LedsatTlmT(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.telemetry_identifier = self._io.read_u2be()
            if not  ((self.telemetry_identifier == 5672) or (self.telemetry_identifier == 5673) or (self.telemetry_identifier == 5674)) :
                raise kaitaistruct.ValidationNotAnyOfError(self.telemetry_identifier, self._io, u"/types/ledsat_tlm_t/seq/0")
            self.unix_ts_ms = self._io.read_u2be()
            self.unix_ts_s = self._io.read_u4be()
            self.tlm_process_time = self._io.read_u2be()
            self.panel_x_voltage = self._io.read_u2be()
            self.panel_y_voltage = self._io.read_u2be()
            self.panel_z_voltage = self._io.read_u2be()
            self.panel_x_current = self._io.read_u2be()
            self.panel_y_current = self._io.read_u2be()
            self.panel_z_current = self._io.read_u2be()
            self.eps_boot_cause = self._io.read_u1()
            self.eps_battery_mode = self._io.read_u1()
            self.mppt_x_temp = self._io.read_s2be()
            self.mppt_y_temp = self._io.read_s2be()
            self.eps_board_temp = self._io.read_s2be()
            self.battery_pack1_temp = self._io.read_s2be()
            self.battery_pack2_temp = self._io.read_s2be()
            self.battery_pack3_temp = self._io.read_s2be()
            self.solar_current = self._io.read_u2be()
            self.system_current = self._io.read_u2be()
            self.battery_voltage = self._io.read_u2be()
            self.gps_current = self._io.read_u1()
            self.pad_0 = self._io.read_u1()
            self.eps_boot_count = self._io.read_u2be()
            self.trx_pa_temp = self._io.read_s2be()
            self.trx_total_tx_cnt = self._io.read_u4be()
            self.trx_total_rx_cnt = self._io.read_u4be()
            self.last_rssi = self._io.read_s2be()
            self.radio_boot_cnt = self._io.read_u2be()
            self.obc_temp_1 = self._io.read_s2be()
            self.obc_temp_2 = self._io.read_s2be()
            self.gyro_x = self._io.read_s2be()
            self.gyro_y = self._io.read_s2be()
            self.gyro_z = self._io.read_s2be()
            self.mag_x = self._io.read_s2be()
            self.mag_y = self._io.read_s2be()
            self.mag_z = self._io.read_s2be()
            self.px_solar_panel_temp = self._io.read_s2be()
            self.py_solar_panel_temp = self._io.read_s2be()
            self.nx_solar_panel_temp = self._io.read_s2be()
            self.ny_solar_panel_temp = self._io.read_s2be()
            self.pz_solar_panel_temp = self._io.read_s2be()
            self.nz_solar_panel_temp = self._io.read_s2be()
            self.px_sun_sensor_coarse = self._io.read_u2be()
            self.py_sun_sensor_coarse = self._io.read_u2be()
            self.pz_sun_sensor_coarse = self._io.read_u2be()
            self.nx_sun_sensor_coarse = self._io.read_u2be()
            self.ny_sun_sensor_coarse = self._io.read_u2be()
            self.nz_sun_sensor_coarse = self._io.read_u2be()
            self.eps_outputs_status = self._io.read_u1()
            self.pad_1 = self._io.read_u1()
            self.obc_boot_counter = self._io.read_s2be()
            self.leds_status = self._io.read_u1()
            self.pad_2 = self._io.read_u1()
            self.gps_status = self._io.read_u1()
            self.pad_3 = self._io.read_u1()
            self.gps_fix_time = self._io.read_u4be()
            self.gps_lat = self._io.read_s4be()
            self.gps_lon = self._io.read_s4be()
            self.gps_alt = self._io.read_s4be()
            self.software_status = self._io.read_u1()
            self.pad_4 = self._io.read_u1()
            self.ext_gyro_x = self._io.read_s2be()
            self.ext_gyro_y = self._io.read_s2be()
            self.ext_gyro_z = self._io.read_s2be()
            self.ext_mag_x = self._io.read_s2be()
            self.ext_mag_y = self._io.read_s2be()
            self.ext_mag_z = self._io.read_s2be()
            self.pad_5 = self._io.read_u2be()


    @property
    def framelength(self):
        if hasattr(self, '_m_framelength'):
            return self._m_framelength if hasattr(self, '_m_framelength') else None

        self._m_framelength = self._io.size()
        return self._m_framelength if hasattr(self, '_m_framelength') else None





# This is a generated file! Please edit source .ksy file and use kaitai-struct-compiler to rebuild

from pkg_resources import parse_version
import kaitaistruct
from kaitaistruct import KaitaiStruct, KaitaiStream, BytesIO


if parse_version(kaitaistruct.__version__) < parse_version('0.9'):
    raise Exception("Incompatible Kaitai Struct Python API: 0.9 or later is required, but you have %s" % (kaitaistruct.__version__))

class Inspiresat1(KaitaiStruct):
    """:field dest_callsign: ax25_frame.ax25_header.dest_callsign_raw.callsign_ror.callsign
    :field src_callsign: ax25_frame.ax25_header.src_callsign_raw.callsign_ror.callsign
    :field src_ssid: ax25_frame.ax25_header.src_ssid_raw.ssid
    :field dest_ssid: ax25_frame.ax25_header.dest_ssid_raw.ssid
    :field ctl: ax25_frame.ax25_header.ctl
    :field pid: ax25_frame.payload.pid
    :field ccsds_version: ax25_frame.payload.ax25_info.ccsds_space_packet.packet_primary_header.ccsds_version
    :field packet_type: ax25_frame.payload.ax25_info.ccsds_space_packet.packet_primary_header.packet_type
    :field secondary_header_flag: ax25_frame.payload.ax25_info.ccsds_space_packet.packet_primary_header.secondary_header_flag
    :field application_process_id: ax25_frame.payload.ax25_info.ccsds_space_packet.packet_primary_header.application_process_id
    :field sequence_flags: ax25_frame.payload.ax25_info.ccsds_space_packet.packet_primary_header.sequence_flags
    :field sequence_count: ax25_frame.payload.ax25_info.ccsds_space_packet.packet_primary_header.sequence_count
    :field packet_length: ax25_frame.payload.ax25_info.ccsds_space_packet.packet_primary_header.packet_length
    :field sh_coarse: ax25_frame.payload.ax25_info.ccsds_space_packet.data_section.secondary_header.sh_coarse
    :field sh_fine: ax25_frame.payload.ax25_info.ccsds_space_packet.data_section.secondary_header.sh_fine
    :field cmd_recv_count: ax25_frame.payload.ax25_info.ccsds_space_packet.data_section.user_data_field.cmd_recv_count
    :field cmd_fail_count: ax25_frame.payload.ax25_info.ccsds_space_packet.data_section.user_data_field.cmd_fail_count
    :field cmd_succ_count: ax25_frame.payload.ax25_info.ccsds_space_packet.data_section.user_data_field.cmd_succ_count
    :field cmd_succ_op: ax25_frame.payload.ax25_info.ccsds_space_packet.data_section.user_data_field.cmd_succ_op
    :field cmd_fail_op: ax25_frame.payload.ax25_info.ccsds_space_packet.data_section.user_data_field.cmd_fail_op
    :field cmd_fail_code: ax25_frame.payload.ax25_info.ccsds_space_packet.data_section.user_data_field.cmd_fail_code
    :field eclipse_state: ax25_frame.payload.ax25_info.ccsds_space_packet.data_section.user_data_field.eclipse_state
    :field pwr_status_sd1: ax25_frame.payload.ax25_info.ccsds_space_packet.data_section.user_data_field.pwr_status_sd1
    :field pwr_status_sd0: ax25_frame.payload.ax25_info.ccsds_space_packet.data_section.user_data_field.pwr_status_sd0
    :field pwr_status_htr: ax25_frame.payload.ax25_info.ccsds_space_packet.data_section.user_data_field.pwr_status_htr
    :field pwr_status_sband: ax25_frame.payload.ax25_info.ccsds_space_packet.data_section.user_data_field.pwr_status_sband
    :field pwr_status_adcs: ax25_frame.payload.ax25_info.ccsds_space_packet.data_section.user_data_field.pwr_status_adcs
    :field pwr_status_cip: ax25_frame.payload.ax25_info.ccsds_space_packet.data_section.user_data_field.pwr_status_cip
    :field pwr_status_daxss: ax25_frame.payload.ax25_info.ccsds_space_packet.data_section.user_data_field.pwr_status_daxss
    :field sd_read_misc: ax25_frame.payload.ax25_info.ccsds_space_packet.data_section.user_data_field.sd_read_misc
    :field sd_read_scic: ax25_frame.payload.ax25_info.ccsds_space_packet.data_section.user_data_field.sd_read_scic
    :field sd_read_scid: ax25_frame.payload.ax25_info.ccsds_space_packet.data_section.user_data_field.sd_read_scid
    :field sd_read_adcs: ax25_frame.payload.ax25_info.ccsds_space_packet.data_section.user_data_field.sd_read_adcs
    :field sd_read_beacon: ax25_frame.payload.ax25_info.ccsds_space_packet.data_section.user_data_field.sd_read_beacon
    :field sd_read_log: ax25_frame.payload.ax25_info.ccsds_space_packet.data_section.user_data_field.sd_read_log
    :field sd_write_misc: ax25_frame.payload.ax25_info.ccsds_space_packet.data_section.user_data_field.sd_write_misc
    :field sd_write_scic: ax25_frame.payload.ax25_info.ccsds_space_packet.data_section.user_data_field.sd_write_scic
    :field sd_write_scid: ax25_frame.payload.ax25_info.ccsds_space_packet.data_section.user_data_field.sd_write_scid
    :field sd_write_adcs: ax25_frame.payload.ax25_info.ccsds_space_packet.data_section.user_data_field.sd_write_adcs
    :field sd_write_beacon: ax25_frame.payload.ax25_info.ccsds_space_packet.data_section.user_data_field.sd_write_beacon
    :field sd_write_log: ax25_frame.payload.ax25_info.ccsds_space_packet.data_section.user_data_field.sd_write_log
    :field cmd_loss_timer: ax25_frame.payload.ax25_info.ccsds_space_packet.data_section.user_data_field.cmd_loss_timer
    :field clt_state: ax25_frame.payload.ax25_info.ccsds_space_packet.data_section.user_data_field.clt_state
    :field alive_daxss: ax25_frame.payload.ax25_info.ccsds_space_packet.data_section.user_data_field.alive_daxss
    :field alive_cip: ax25_frame.payload.ax25_info.ccsds_space_packet.data_section.user_data_field.alive_cip
    :field alive_adcs: ax25_frame.payload.ax25_info.ccsds_space_packet.data_section.user_data_field.alive_adcs
    :field alive_sband: ax25_frame.payload.ax25_info.ccsds_space_packet.data_section.user_data_field.alive_sband
    :field alive_uhf: ax25_frame.payload.ax25_info.ccsds_space_packet.data_section.user_data_field.alive_uhf
    :field alive_sd1: ax25_frame.payload.ax25_info.ccsds_space_packet.data_section.user_data_field.alive_sd1
    :field alive_sd0: ax25_frame.payload.ax25_info.ccsds_space_packet.data_section.user_data_field.alive_sd0
    :field cip_comstat: ax25_frame.payload.ax25_info.ccsds_space_packet.data_section.user_data_field.cip_comstat
    :field cip_temp1: ax25_frame.payload.ax25_info.ccsds_space_packet.data_section.user_data_field.cip_temp1
    :field cip_temp2: ax25_frame.payload.ax25_info.ccsds_space_packet.data_section.user_data_field.cip_temp2
    :field cip_temp3: ax25_frame.payload.ax25_info.ccsds_space_packet.data_section.user_data_field.cip_temp3
    :field uhf_temp_buff: ax25_frame.payload.ax25_info.ccsds_space_packet.data_section.user_data_field.uhf_temp_buff
    :field uhf_temp: ax25_frame.payload.ax25_info.ccsds_space_packet.data_section.user_data_field.uhf_temp
    :field uhf_locked: ax25_frame.payload.ax25_info.ccsds_space_packet.data_section.user_data_field.uhf_locked
    :field uhf_readback: ax25_frame.payload.ax25_info.ccsds_space_packet.data_section.user_data_field.uhf_readback
    :field uhf_swd: ax25_frame.payload.ax25_info.ccsds_space_packet.data_section.user_data_field.uhf_swd
    :field uhf_afc: ax25_frame.payload.ax25_info.ccsds_space_packet.data_section.user_data_field.uhf_afc
    :field uhf_echo: ax25_frame.payload.ax25_info.ccsds_space_packet.data_section.user_data_field.uhf_echo
    :field uhf_channel: ax25_frame.payload.ax25_info.ccsds_space_packet.data_section.user_data_field.uhf_channel
    :field sband_pa_curr: ax25_frame.payload.ax25_info.ccsds_space_packet.data_section.user_data_field.sband_pa_curr
    :field sband_pa_volt: ax25_frame.payload.ax25_info.ccsds_space_packet.data_section.user_data_field.sband_pa_volt
    :field sband_rf_pwr: ax25_frame.payload.ax25_info.ccsds_space_packet.data_section.user_data_field.sband_rf_pwr
    :field sband_pa_temp: ax25_frame.payload.ax25_info.ccsds_space_packet.data_section.user_data_field.sband_pa_temp
    :field sband_top_temp: ax25_frame.payload.ax25_info.ccsds_space_packet.data_section.user_data_field.sband_top_temp
    :field sband_bottom_temp: ax25_frame.payload.ax25_info.ccsds_space_packet.data_section.user_data_field.sband_bottom_temp
    :field adcs_cmd_acpt: ax25_frame.payload.ax25_info.ccsds_space_packet.data_section.user_data_field.adcs_cmd_acpt
    :field adcs_cmd_fail: ax25_frame.payload.ax25_info.ccsds_space_packet.data_section.user_data_field.adcs_cmd_fail
    :field adcs_time: ax25_frame.payload.ax25_info.ccsds_space_packet.data_section.user_data_field.adcs_time
    :field adcs_att_valid: ax25_frame.payload.ax25_info.ccsds_space_packet.data_section.user_data_field.adcs_att_valid
    :field adcs_refs_valid: ax25_frame.payload.ax25_info.ccsds_space_packet.data_section.user_data_field.adcs_refs_valid
    :field adcs_time_valid: ax25_frame.payload.ax25_info.ccsds_space_packet.data_section.user_data_field.adcs_time_valid
    :field adcs_mode: ax25_frame.payload.ax25_info.ccsds_space_packet.data_section.user_data_field.adcs_mode
    :field adcs_recom_sun_pt: ax25_frame.payload.ax25_info.ccsds_space_packet.data_section.user_data_field.adcs_recom_sun_pt
    :field adcs_sun_pt_state: ax25_frame.payload.ax25_info.ccsds_space_packet.data_section.user_data_field.adcs_sun_pt_state
    :field adcs_star_temp: ax25_frame.payload.ax25_info.ccsds_space_packet.data_section.user_data_field.adcs_star_temp
    :field adcs_wheel_temp1: ax25_frame.payload.ax25_info.ccsds_space_packet.data_section.user_data_field.adcs_wheel_temp1
    :field adcs_wheel_temp2: ax25_frame.payload.ax25_info.ccsds_space_packet.data_section.user_data_field.adcs_wheel_temp2
    :field adcs_wheel_temp3: ax25_frame.payload.ax25_info.ccsds_space_packet.data_section.user_data_field.adcs_wheel_temp3
    :field adcs_digi_bus_volt: ax25_frame.payload.ax25_info.ccsds_space_packet.data_section.user_data_field.adcs_digi_bus_volt
    :field adcs_sun_vec1: ax25_frame.payload.ax25_info.ccsds_space_packet.data_section.user_data_field.adcs_sun_vec1
    :field adcs_sun_vec2: ax25_frame.payload.ax25_info.ccsds_space_packet.data_section.user_data_field.adcs_sun_vec2
    :field adcs_sun_vec3: ax25_frame.payload.ax25_info.ccsds_space_packet.data_section.user_data_field.adcs_sun_vec3
    :field adcs_wheel_sp1: ax25_frame.payload.ax25_info.ccsds_space_packet.data_section.user_data_field.adcs_wheel_sp1
    :field adcs_wheel_sp2: ax25_frame.payload.ax25_info.ccsds_space_packet.data_section.user_data_field.adcs_wheel_sp2
    :field adcs_wheel_sp3: ax25_frame.payload.ax25_info.ccsds_space_packet.data_section.user_data_field.adcs_wheel_sp3
    :field adcs_body_rt1: ax25_frame.payload.ax25_info.ccsds_space_packet.data_section.user_data_field.adcs_body_rt1
    :field adcs_body_rt2: ax25_frame.payload.ax25_info.ccsds_space_packet.data_section.user_data_field.adcs_body_rt2
    :field adcs_body_rt3: ax25_frame.payload.ax25_info.ccsds_space_packet.data_section.user_data_field.adcs_body_rt3
    :field daxss_time_sec: ax25_frame.payload.ax25_info.ccsds_space_packet.data_section.user_data_field.daxss_time_sec
    :field daxss_cmd_op: ax25_frame.payload.ax25_info.ccsds_space_packet.data_section.user_data_field.daxss_cmd_op
    :field daxss_cmd_succ: ax25_frame.payload.ax25_info.ccsds_space_packet.data_section.user_data_field.daxss_cmd_succ
    :field daxss_cmd_fail: ax25_frame.payload.ax25_info.ccsds_space_packet.data_section.user_data_field.daxss_cmd_fail
    :field daxss_cdh_enables: ax25_frame.payload.ax25_info.ccsds_space_packet.data_section.user_data_field.daxss_cdh_enables
    :field daxss_cdh_temp: ax25_frame.payload.ax25_info.ccsds_space_packet.data_section.user_data_field.daxss_cdh_temp
    :field daxss_sps_rate: ax25_frame.payload.ax25_info.ccsds_space_packet.data_section.user_data_field.daxss_sps_rate
    :field daxss_sps_x: ax25_frame.payload.ax25_info.ccsds_space_packet.data_section.user_data_field.daxss_sps_x
    :field daxss_sps_y: ax25_frame.payload.ax25_info.ccsds_space_packet.data_section.user_data_field.daxss_sps_y
    :field daxss_slow_count: ax25_frame.payload.ax25_info.ccsds_space_packet.data_section.user_data_field.daxss_slow_count
    :field bat_fg1: ax25_frame.payload.ax25_info.ccsds_space_packet.data_section.user_data_field.bat_fg1
    :field daxss_curr: ax25_frame.payload.ax25_info.ccsds_space_packet.data_section.user_data_field.daxss_curr
    :field daxss_volt: ax25_frame.payload.ax25_info.ccsds_space_packet.data_section.user_data_field.daxss_volt
    :field cdh_curr: ax25_frame.payload.ax25_info.ccsds_space_packet.data_section.user_data_field.cdh_curr
    :field cdh_volt: ax25_frame.payload.ax25_info.ccsds_space_packet.data_section.user_data_field.cdh_volt
    :field sband_curr: ax25_frame.payload.ax25_info.ccsds_space_packet.data_section.user_data_field.sband_curr
    :field sband_volt: ax25_frame.payload.ax25_info.ccsds_space_packet.data_section.user_data_field.sband_volt
    :field uhf_curr: ax25_frame.payload.ax25_info.ccsds_space_packet.data_section.user_data_field.uhf_curr
    :field uhf_volt: ax25_frame.payload.ax25_info.ccsds_space_packet.data_section.user_data_field.uhf_volt
    :field heater_curr: ax25_frame.payload.ax25_info.ccsds_space_packet.data_section.user_data_field.heater_curr
    :field heater_volt: ax25_frame.payload.ax25_info.ccsds_space_packet.data_section.user_data_field.heater_volt
    :field sp2_curr: ax25_frame.payload.ax25_info.ccsds_space_packet.data_section.user_data_field.sp2_curr
    :field sp2_volt: ax25_frame.payload.ax25_info.ccsds_space_packet.data_section.user_data_field.sp2_volt
    :field sp1_curr: ax25_frame.payload.ax25_info.ccsds_space_packet.data_section.user_data_field.sp1_curr
    :field sp1_volt: ax25_frame.payload.ax25_info.ccsds_space_packet.data_section.user_data_field.sp1_volt
    :field sp0_curr: ax25_frame.payload.ax25_info.ccsds_space_packet.data_section.user_data_field.sp0_curr
    :field sp0_volt: ax25_frame.payload.ax25_info.ccsds_space_packet.data_section.user_data_field.sp0_volt
    :field bat_vcell: ax25_frame.payload.ax25_info.ccsds_space_packet.data_section.user_data_field.bat_vcell
    :field gps_12v_2_curr: ax25_frame.payload.ax25_info.ccsds_space_packet.data_section.user_data_field.gps_12v_2_curr
    :field gps_12v_2_volt: ax25_frame.payload.ax25_info.ccsds_space_packet.data_section.user_data_field.gps_12v_2_volt
    :field gps_12v_1_curr: ax25_frame.payload.ax25_info.ccsds_space_packet.data_section.user_data_field.gps_12v_1_curr
    :field gps_12v_1_volt: ax25_frame.payload.ax25_info.ccsds_space_packet.data_section.user_data_field.gps_12v_1_volt
    :field bat_curr: ax25_frame.payload.ax25_info.ccsds_space_packet.data_section.user_data_field.bat_curr
    :field bat_volt: ax25_frame.payload.ax25_info.ccsds_space_packet.data_section.user_data_field.bat_volt
    :field adcs_curr: ax25_frame.payload.ax25_info.ccsds_space_packet.data_section.user_data_field.adcs_curr
    :field adcs_volt: ax25_frame.payload.ax25_info.ccsds_space_packet.data_section.user_data_field.adcs_volt
    :field v3p3_curr: ax25_frame.payload.ax25_info.ccsds_space_packet.data_section.user_data_field.v3p3_curr
    :field v3p3_volt: ax25_frame.payload.ax25_info.ccsds_space_packet.data_section.user_data_field.v3p3_volt
    :field cip_curr: ax25_frame.payload.ax25_info.ccsds_space_packet.data_section.user_data_field.cip_curr
    :field cip_volt: ax25_frame.payload.ax25_info.ccsds_space_packet.data_section.user_data_field.cip_volt
    :field obc_temp: ax25_frame.payload.ax25_info.ccsds_space_packet.data_section.user_data_field.obc_temp
    :field eps_temp: ax25_frame.payload.ax25_info.ccsds_space_packet.data_section.user_data_field.eps_temp
    :field int_temp: ax25_frame.payload.ax25_info.ccsds_space_packet.data_section.user_data_field.int_temp
    :field sp0_temp: ax25_frame.payload.ax25_info.ccsds_space_packet.data_section.user_data_field.sp0_temp
    :field bat0_temp: ax25_frame.payload.ax25_info.ccsds_space_packet.data_section.user_data_field.bat0_temp
    :field sp1_temp: ax25_frame.payload.ax25_info.ccsds_space_packet.data_section.user_data_field.sp1_temp
    :field bat1_temp: ax25_frame.payload.ax25_info.ccsds_space_packet.data_section.user_data_field.bat1_temp
    :field sp2_temp: ax25_frame.payload.ax25_info.ccsds_space_packet.data_section.user_data_field.sp2_temp
    :field bat_fg3: ax25_frame.payload.ax25_info.ccsds_space_packet.data_section.user_data_field.bat_fg3
    :field bat0_temp_conv: ax25_frame.payload.ax25_info.ccsds_space_packet.data_section.user_data_field.bat0_temp_conv
    :field bat1_temp_conv: ax25_frame.payload.ax25_info.ccsds_space_packet.data_section.user_data_field.bat1_temp_conv
    :field mode: ax25_frame.payload.ax25_info.ccsds_space_packet.data_section.user_data_field.mode
    """
    def __init__(self, _io, _parent=None, _root=None):
        self._io = _io
        self._parent = _parent
        self._root = _root if _root else self
        self._read()

    def _read(self):
        self.ax25_frame = Inspiresat1.Ax25Frame(self._io, self, self._root)

    class Ax25Frame(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.ax25_header = Inspiresat1.Ax25Header(self._io, self, self._root)
            _on = (self.ax25_header.ctl & 19)
            if _on == 0:
                self.payload = Inspiresat1.IFrame(self._io, self, self._root)
            elif _on == 3:
                self.payload = Inspiresat1.UiFrame(self._io, self, self._root)
            elif _on == 19:
                self.payload = Inspiresat1.UiFrame(self._io, self, self._root)
            elif _on == 16:
                self.payload = Inspiresat1.IFrame(self._io, self, self._root)
            elif _on == 18:
                self.payload = Inspiresat1.IFrame(self._io, self, self._root)
            elif _on == 2:
                self.payload = Inspiresat1.IFrame(self._io, self, self._root)


    class Ax25Header(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.dest_callsign_raw = Inspiresat1.CallsignRaw(self._io, self, self._root)
            self.dest_ssid_raw = Inspiresat1.SsidMask(self._io, self, self._root)
            self.src_callsign_raw = Inspiresat1.CallsignRaw(self._io, self, self._root)
            self.src_ssid_raw = Inspiresat1.SsidMask(self._io, self, self._root)
            self.ctl = self._io.read_u1()


    class UiFrame(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.pid = self._io.read_u1()
            self._raw_ax25_info = self._io.read_bytes_full()
            _io__raw_ax25_info = KaitaiStream(BytesIO(self._raw_ax25_info))
            self.ax25_info = Inspiresat1.Ax25InfoData(_io__raw_ax25_info, self, self._root)


    class Callsign(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.callsign = (self._io.read_bytes(6)).decode(u"ASCII")
            if not  ((self.callsign == u"IS-1  ") or (self.callsign == u"BCT   ")) :
                raise kaitaistruct.ValidationNotAnyOfError(self.callsign, self._io, u"/types/callsign/seq/0")


    class IFrame(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.pid = self._io.read_u1()
            self._raw_ax25_info = self._io.read_bytes_full()
            _io__raw_ax25_info = KaitaiStream(BytesIO(self._raw_ax25_info))
            self.ax25_info = Inspiresat1.Ax25InfoData(_io__raw_ax25_info, self, self._root)


    class SsidMask(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.ssid_mask = self._io.read_u1()

        @property
        def ssid(self):
            if hasattr(self, '_m_ssid'):
                return self._m_ssid if hasattr(self, '_m_ssid') else None

            self._m_ssid = ((self.ssid_mask & 15) >> 1)
            return self._m_ssid if hasattr(self, '_m_ssid') else None


    class DataSectionT(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            if self._parent.packet_primary_header.secondary_header_flag:
                self._raw_secondary_header = self._io.read_bytes(6)
                _io__raw_secondary_header = KaitaiStream(BytesIO(self._raw_secondary_header))
                self.secondary_header = Inspiresat1.SecondaryHeaderT(_io__raw_secondary_header, self, self._root)

            _on = self._parent.packet_primary_header.application_process_id
            if _on == 1:
                self.user_data_field = Inspiresat1.Is1BeaconT(self._io, self, self._root)


    class SecondaryHeaderT(KaitaiStruct):
        """The Secondary Header is a feature of the Space Packet which allows
        additional types of information that may be useful to the user
        application (e.g., a time code) to be included.
        See: 4.1.3.2 in CCSDS 133.0-B-1
        """
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.sh_coarse = self._io.read_u4le()
            self.sh_fine = self._io.read_u2le()


    class PacketPrimaryHeaderT(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.ccsds_version = self._io.read_bits_int_be(3)
            self.packet_type = self._io.read_bits_int_be(1) != 0
            self.secondary_header_flag = self._io.read_bits_int_be(1) != 0
            self.application_process_id = self._io.read_bits_int_be(11)
            self.sequence_flags = self._io.read_bits_int_be(2)
            self.sequence_count = self._io.read_bits_int_be(14)
            self._io.align_to_byte()
            self.packet_length = self._io.read_u2be()


    class CallsignRaw(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self._raw__raw_callsign_ror = self._io.read_bytes(6)
            self._raw_callsign_ror = KaitaiStream.process_rotate_left(self._raw__raw_callsign_ror, 8 - (1), 1)
            _io__raw_callsign_ror = KaitaiStream(BytesIO(self._raw_callsign_ror))
            self.callsign_ror = Inspiresat1.Callsign(_io__raw_callsign_ror, self, self._root)


    class Is1BeaconT(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.cmd_recv_count = self._io.read_u1()
            self.cmd_fail_count = self._io.read_u1()
            self.cmd_succ_count = self._io.read_u1()
            self.cmd_succ_op = self._io.read_u1()
            self.cmd_fail_op = self._io.read_u1()
            self.cmd_fail_code = self._io.read_u1()
            self.eclipse_state = self._io.read_bits_int_be(1) != 0
            self.pwr_status_sd1 = self._io.read_bits_int_be(1) != 0
            self.pwr_status_sd0 = self._io.read_bits_int_be(1) != 0
            self.pwr_status_htr = self._io.read_bits_int_be(1) != 0
            self.pwr_status_sband = self._io.read_bits_int_be(1) != 0
            self.pwr_status_adcs = self._io.read_bits_int_be(1) != 0
            self.pwr_status_cip = self._io.read_bits_int_be(1) != 0
            self.pwr_status_daxss = self._io.read_bits_int_be(1) != 0
            self._io.align_to_byte()
            self.sd_read_misc = self._io.read_u4le()
            self.sd_read_scic = self._io.read_u4le()
            self.sd_read_scid = self._io.read_u4le()
            self.sd_read_adcs = self._io.read_u4le()
            self.sd_read_beacon = self._io.read_u4le()
            self.sd_read_log = self._io.read_u4le()
            self.sd_write_misc = self._io.read_u4le()
            self.sd_write_scic = self._io.read_u4le()
            self.sd_write_scid = self._io.read_u4le()
            self.sd_write_adcs = self._io.read_u4le()
            self.sd_write_beacon = self._io.read_u4le()
            self.sd_write_log = self._io.read_u4le()
            self.cmd_loss_timer = self._io.read_u4le()
            self.clt_state = self._io.read_bits_int_be(1) != 0
            self.alive_daxss = self._io.read_bits_int_be(1) != 0
            self.alive_cip = self._io.read_bits_int_be(1) != 0
            self.alive_adcs = self._io.read_bits_int_be(1) != 0
            self.alive_sband = self._io.read_bits_int_be(1) != 0
            self.alive_uhf = self._io.read_bits_int_be(1) != 0
            self.alive_sd1 = self._io.read_bits_int_be(1) != 0
            self.alive_sd0 = self._io.read_bits_int_be(1) != 0
            self._io.align_to_byte()
            self.cip_comstat = self._io.read_u4le()
            self.cip_temp1 = self._io.read_s2le()
            self.cip_temp2 = self._io.read_s2le()
            self.cip_temp3 = self._io.read_s2le()
            self.uhf_temp_buff = self._io.read_bits_int_be(2)
            self.uhf_temp = self._io.read_bits_int_be(6)
            self.uhf_locked = self._io.read_bits_int_be(1) != 0
            self.uhf_readback = self._io.read_bits_int_be(2)
            self.uhf_swd = self._io.read_bits_int_be(1) != 0
            self.uhf_afc = self._io.read_bits_int_be(1) != 0
            self.uhf_echo = self._io.read_bits_int_be(1) != 0
            self.uhf_channel = self._io.read_bits_int_be(2)
            self._io.align_to_byte()
            self.sband_pa_curr = self._io.read_u2le()
            self.sband_pa_volt = self._io.read_u2le()
            self.sband_rf_pwr = self._io.read_u2le()
            self.sband_pa_temp = self._io.read_u2le()
            self.sband_top_temp = self._io.read_u2le()
            self.sband_bottom_temp = self._io.read_u2le()
            self.adcs_cmd_acpt = self._io.read_u1()
            self.adcs_cmd_fail = self._io.read_u1()
            self.adcs_time = self._io.read_s4le()
            self.adcs_att_valid = self._io.read_bits_int_be(1) != 0
            self.adcs_refs_valid = self._io.read_bits_int_be(1) != 0
            self.adcs_time_valid = self._io.read_bits_int_be(1) != 0
            self.adcs_mode = self._io.read_bits_int_be(1) != 0
            self.adcs_recom_sun_pt = self._io.read_bits_int_be(1) != 0
            self.adcs_sun_pt_state = self._io.read_bits_int_be(3)
            self._io.align_to_byte()
            self.adcs_star_temp = self._io.read_s1()
            self.adcs_wheel_temp1 = self._io.read_s2le()
            self.adcs_wheel_temp2 = self._io.read_s2le()
            self.adcs_wheel_temp3 = self._io.read_s2le()
            self.adcs_digi_bus_volt = self._io.read_s2le()
            self.adcs_sun_vec1 = self._io.read_s2le()
            self.adcs_sun_vec2 = self._io.read_s2le()
            self.adcs_sun_vec3 = self._io.read_s2le()
            self.adcs_wheel_sp1 = self._io.read_s2le()
            self.adcs_wheel_sp2 = self._io.read_s2le()
            self.adcs_wheel_sp3 = self._io.read_s2le()
            self.adcs_body_rt1 = self._io.read_s4le()
            self.adcs_body_rt2 = self._io.read_s4le()
            self.adcs_body_rt3 = self._io.read_s4le()
            self.pad1 = self._io.read_u4le()
            self.pad2 = self._io.read_u4le()
            self.pad3 = self._io.read_u4le()
            self.daxss_time_sec = self._io.read_u4le()
            self.daxss_cmd_op = self._io.read_u1()
            self.daxss_cmd_succ = self._io.read_u1()
            self.daxss_cmd_fail = self._io.read_u1()
            self.daxss_cdh_enables = self._io.read_u2le()
            self.daxss_cdh_temp = self._io.read_s2le()
            self.daxss_sps_rate = self._io.read_u4le()
            self.daxss_sps_x = self._io.read_u2le()
            self.daxss_sps_y = self._io.read_u2le()
            self.daxss_slow_count = self._io.read_u2le()
            self.bat_fg1 = self._io.read_u2le()
            self.daxss_curr = self._io.read_u2le()
            self.daxss_volt = self._io.read_u2le()
            self.cdh_curr = self._io.read_u2le()
            self.cdh_volt = self._io.read_u2le()
            self.sband_curr = self._io.read_u2le()
            self.sband_volt = self._io.read_u2le()
            self.uhf_curr = self._io.read_u2le()
            self.uhf_volt = self._io.read_u2le()
            self.heater_curr = self._io.read_u2le()
            self.heater_volt = self._io.read_u2le()
            self.sp2_curr = self._io.read_u2le()
            self.sp2_volt = self._io.read_u2le()
            self.sp1_curr = self._io.read_u2le()
            self.sp1_volt = self._io.read_u2le()
            self.sp0_curr = self._io.read_u2le()
            self.sp0_volt = self._io.read_u2le()
            self.bat_vcell = self._io.read_u2le()
            self.gps_12v_2_curr = self._io.read_u2le()
            self.gps_12v_2_volt = self._io.read_u2le()
            self.gps_12v_1_curr = self._io.read_u2le()
            self.gps_12v_1_volt = self._io.read_u2le()
            self.bat_curr = self._io.read_u2le()
            self.bat_volt = self._io.read_u2le()
            self.adcs_curr = self._io.read_u2le()
            self.adcs_volt = self._io.read_u2le()
            self.v3p3_curr = self._io.read_u2le()
            self.v3p3_volt = self._io.read_u2le()
            self.cip_curr = self._io.read_u2le()
            self.cip_volt = self._io.read_u2le()
            self.obc_temp = self._io.read_u2le()
            self.eps_temp = self._io.read_u2le()
            self.int_temp = self._io.read_u2le()
            self.sp0_temp = self._io.read_u2le()
            self.bat0_temp = self._io.read_u2le()
            self.sp1_temp = self._io.read_u2le()
            self.bat1_temp = self._io.read_u2le()
            self.sp2_temp = self._io.read_u2le()
            self.bat_fg3 = self._io.read_u2le()
            self.bat0_temp_conv = self._io.read_f4le()
            self.bat1_temp_conv = self._io.read_f4le()
            self.mode = self._io.read_u1()


    class CcsdsSpacePacketT(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self._raw_packet_primary_header = self._io.read_bytes(6)
            _io__raw_packet_primary_header = KaitaiStream(BytesIO(self._raw_packet_primary_header))
            self.packet_primary_header = Inspiresat1.PacketPrimaryHeaderT(_io__raw_packet_primary_header, self, self._root)
            self.data_section = Inspiresat1.DataSectionT(self._io, self, self._root)


    class Ax25InfoData(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.ccsds_space_packet = Inspiresat1.CcsdsSpacePacketT(self._io, self, self._root)






# This is a generated file! Please edit source .ksy file and use kaitai-struct-compiler to rebuild

from pkg_resources import parse_version
import kaitaistruct
from kaitaistruct import KaitaiStruct, KaitaiStream, BytesIO


if parse_version(kaitaistruct.__version__) < parse_version('0.9'):
    raise Exception("Incompatible Kaitai Struct Python API: 0.9 or later is required, but you have %s" % (kaitaistruct.__version__))

class Polyitan1(KaitaiStruct):
    """:field dst_callsign: ax25_frame.ax25_header.dest_callsign_raw.callsign_ror.callsign
    :field src_callsign: ax25_frame.ax25_header.src_callsign_raw.callsign_ror.callsign
    :field ctl: ax25_frame.ax25_header.ctl
    :field pid: ax25_frame.payload.pid
    :field data_type: ax25_frame.payload.ax25_info.header.data_type
    :field beacon0: ax25_frame.payload.ax25_info.data.body
    :field device_err1_raw: ax25_frame.payload.ax25_info.data.device_err1_raw
    :field device_err2_raw: ax25_frame.payload.ax25_info.data.device_err2_raw
    :field device_err3_raw: ax25_frame.payload.ax25_info.data.device_err3_raw
    :field ss256: ax25_frame.payload.ax25_info.data.ss256
    :field rtc_s: ax25_frame.payload.ax25_info.data.rtc_s
    :field sat_mode: ax25_frame.payload.ax25_info.data.sat_mode
    :field submode: ax25_frame.payload.ax25_info.data.submode
    :field mux_i3_3: ax25_frame.payload.ax25_info.data.mux_i3_3
    :field arege: ax25_frame.payload.ax25_info.data.arege
    :field eab1: ax25_frame.payload.ax25_info.data.eab1
    :field eab2: ax25_frame.payload.ax25_info.data.eab2
    :field eab3: ax25_frame.payload.ax25_info.data.eab3
    :field v_acb: ax25_frame.payload.ax25_info.data.v_acb
    :field cab1: ax25_frame.payload.ax25_info.data.cab1
    :field cab2: ax25_frame.payload.ax25_info.data.cab2
    :field cab3: ax25_frame.payload.ax25_info.data.cab3
    :field c_from_sb_all: ax25_frame.payload.ax25_info.data.c_from_sb_all
    :field curr_sp_main: ax25_frame.payload.ax25_info.data.curr_sp_main
    :field c_load_all: ax25_frame.payload.ax25_info.data.c_load_all
    :field p_sbx: ax25_frame.payload.ax25_info.data.p_sbx
    :field p_sby: ax25_frame.payload.ax25_info.data.p_sby
    :field p_sbz: ax25_frame.payload.ax25_info.data.p_sbz
    :field device_errors: ax25_frame.payload.ax25_info.data.device_errors
    :field magtl_x: ax25_frame.payload.ax25_info.data.magtl_x
    :field magtl_y: ax25_frame.payload.ax25_info.data.magtl_y
    :field magtl_z: ax25_frame.payload.ax25_info.data.magtl_z
    :field gyro_x_mdps: ax25_frame.payload.ax25_info.data.gyro_x_mdps
    :field gyro_y_mdps: ax25_frame.payload.ax25_info.data.gyro_y_mdps
    :field gyro_z_mdps: ax25_frame.payload.ax25_info.data.gyro_z_mdps
    :field mux_i5_0: ax25_frame.payload.ax25_info.data.mux_i5_0
    :field ads1248_tmp_c: ax25_frame.payload.ax25_info.data.ads1248_tmp_c
    :field charge: ax25_frame.payload.ax25_info.data.charge
    :field antennas_status: ax25_frame.payload.ax25_info.data.antennas_status
    :field t_ab1: ax25_frame.payload.ax25_info.data.t_ab1
    :field t_ab2: ax25_frame.payload.ax25_info.data.t_ab2
    :field t_ab3: ax25_frame.payload.ax25_info.data.t_ab3
    :field mode: ax25_frame.payload.ax25_info.data.mode
    :field device_status: ax25_frame.payload.ax25_info.info.data.device_status
    :field rtc_ss: ax25_frame.payload.ax25_info.data.rtc_ss
    :field u_3_3v_digi: ax25_frame.payload.ax25_info.data.u_3_3v_digi
    :field u_3_3v_rf: ax25_frame.payload.ax25_info.data.u_3_3v_rf
    :field u_3_3v_rf_amp: ax25_frame.payload.ax25_info.data.u_3_3v_rf_amp
    :field temp2: ax25_frame.payload.ax25_info.data.temp2
    :field temp1: ax25_frame.payload.ax25_info.data.temp1
    
    .. seealso::
       Source - https://amsat.vhfdx.in.ua/documents/polyitan.ksy
    """
    def __init__(self, _io, _parent=None, _root=None):
        self._io = _io
        self._parent = _parent
        self._root = _root if _root else self
        self._read()

    def _read(self):
        self.ax25_frame = Polyitan1.Ax25Frame(self._io, self, self._root)

    class Ax25Frame(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.ax25_header = Polyitan1.Ax25Header(self._io, self, self._root)
            _on = (self.ax25_header.ctl & 19)
            if _on == 0:
                self.payload = Polyitan1.IFrame(self._io, self, self._root)
            elif _on == 3:
                self.payload = Polyitan1.UiFrame(self._io, self, self._root)
            elif _on == 19:
                self.payload = Polyitan1.UiFrame(self._io, self, self._root)
            elif _on == 16:
                self.payload = Polyitan1.IFrame(self._io, self, self._root)
            elif _on == 18:
                self.payload = Polyitan1.IFrame(self._io, self, self._root)
            elif _on == 2:
                self.payload = Polyitan1.IFrame(self._io, self, self._root)


    class Ax25Header(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.dest_callsign_raw = Polyitan1.CallsignRaw(self._io, self, self._root)
            self.dest_ssid_raw = Polyitan1.SsidMask(self._io, self, self._root)
            self.src_callsign_raw = Polyitan1.CallsignRaw(self._io, self, self._root)
            self.src_ssid_raw = Polyitan1.SsidMask(self._io, self, self._root)
            self.ctl = self._io.read_u1()


    class UiFrame(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.pid = self._io.read_u1()
            _on = self._parent.ax25_header.src_callsign_raw.callsign_ror.callsign
            if _on == u"EM0UKP":
                self._raw_ax25_info = self._io.read_bytes_full()
                _io__raw_ax25_info = KaitaiStream(BytesIO(self._raw_ax25_info))
                self.ax25_info = Polyitan1.Ax25Info(_io__raw_ax25_info, self, self._root)
            else:
                self.ax25_info = self._io.read_bytes_full()


    class Callsign(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.callsign = (self._io.read_bytes(6)).decode(u"ASCII")


    class Beacon1(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.device_err1_raw = self._io.read_u1()
            self.device_err2_raw = self._io.read_u1()
            self.device_err3_raw = self._io.read_u1()
            self.ss256 = self._io.read_u1()
            self.rtc_s = self._io.read_s4le()
            self.sat_mode = self._io.read_u1()
            self.submode = self._io.read_u1()
            self.magtl_x1_raw = self._io.read_u1()
            self.magtl_x2_raw = self._io.read_u1()
            self.magtl_x3_raw = self._io.read_u1()
            self.magtl_y1_raw = self._io.read_u1()
            self.magtl_y2_raw = self._io.read_u1()
            self.magtl_y3_raw = self._io.read_u1()
            self.magtl_z1_raw = self._io.read_u1()
            self.magtl_z2_raw = self._io.read_u1()
            self.magtl_z3_raw = self._io.read_u1()
            self.gyro_x1_mdps_raw = self._io.read_u1()
            self.gyro_x2_mdps_raw = self._io.read_u1()
            self.gyro_x3_mdps_raw = self._io.read_u1()
            self.gyro_y1_mdps_raw = self._io.read_u1()
            self.gyro_y2_mdps_raw = self._io.read_u1()
            self.gyro_y3_mdps_raw = self._io.read_u1()
            self.gyro_z1_mdps_raw = self._io.read_u1()
            self.gyro_z2_mdps_raw = self._io.read_u1()
            self.gyro_z3_mdps_raw = self._io.read_u1()
            self.mux_i3_3 = self._io.read_u2le()
            self.mux_i5_0_raw = self._io.read_u2le()
            self.ads1248_tmp_c_raw = self._io.read_s2le()
            self.arege = self._io.read_u2le()
            self.antennas_status_raw = self._io.read_u2le()
            self.charge_raw = self._io.read_u2be()
            self.eab1 = self._io.read_u2le()
            self.eab2 = self._io.read_u2le()
            self.eab3 = self._io.read_u2le()
            self.v_acb = self._io.read_s2le()
            self.cab1 = self._io.read_s2le()
            self.cab2 = self._io.read_s2le()
            self.cab3 = self._io.read_s2le()
            self.c_from_sb_all = self._io.read_s2le()
            self.curr_sp_main = self._io.read_u2le()
            self.c_load_all = self._io.read_s2le()
            self.t_ab2_raw = self._io.read_s2le()
            self.t_ab3_raw = self._io.read_s2le()
            self.p_sbx = self._io.read_s2le()
            self.p_sby = self._io.read_s2le()
            self.p_sbz = self._io.read_s2le()

        @property
        def device_errors(self):
            """non zero if orientation enabled."""
            if hasattr(self, '_m_device_errors'):
                return self._m_device_errors if hasattr(self, '_m_device_errors') else None

            self._m_device_errors = (((self.device_err3_raw << 16) | (self.device_err2_raw << 8)) | self.device_err1_raw)
            return self._m_device_errors if hasattr(self, '_m_device_errors') else None

        @property
        def charge(self):
            if hasattr(self, '_m_charge'):
                return self._m_charge if hasattr(self, '_m_charge') else None

            self._m_charge = (self.charge_raw * 0.1)
            return self._m_charge if hasattr(self, '_m_charge') else None

        @property
        def magtl_y(self):
            """non zero if orientation enabled."""
            if hasattr(self, '_m_magtl_y'):
                return self._m_magtl_y if hasattr(self, '_m_magtl_y') else None

            self._m_magtl_y = (((self.magtl_y3_raw << 16) | (self.magtl_y2_raw << 8)) | self.magtl_y1_raw)
            return self._m_magtl_y if hasattr(self, '_m_magtl_y') else None

        @property
        def t_ab3(self):
            if hasattr(self, '_m_t_ab3'):
                return self._m_t_ab3 if hasattr(self, '_m_t_ab3') else None

            self._m_t_ab3 = (self.t_ab3_raw * 0.1)
            return self._m_t_ab3 if hasattr(self, '_m_t_ab3') else None

        @property
        def ads1248_tmp_c(self):
            if hasattr(self, '_m_ads1248_tmp_c'):
                return self._m_ads1248_tmp_c if hasattr(self, '_m_ads1248_tmp_c') else None

            self._m_ads1248_tmp_c = (self.ads1248_tmp_c_raw * 0.1)
            return self._m_ads1248_tmp_c if hasattr(self, '_m_ads1248_tmp_c') else None

        @property
        def magtl_z(self):
            """non zero if orientation enabled."""
            if hasattr(self, '_m_magtl_z'):
                return self._m_magtl_z if hasattr(self, '_m_magtl_z') else None

            self._m_magtl_z = (((self.magtl_z3_raw << 16) | (self.magtl_z2_raw << 8)) | self.magtl_z1_raw)
            return self._m_magtl_z if hasattr(self, '_m_magtl_z') else None

        @property
        def antennas_status(self):
            """not set."""
            if hasattr(self, '_m_antennas_status'):
                return self._m_antennas_status if hasattr(self, '_m_antennas_status') else None

            self._m_antennas_status = (self.antennas_status_raw & 15)
            return self._m_antennas_status if hasattr(self, '_m_antennas_status') else None

        @property
        def gyro_x_mdps(self):
            """non zero if orientation enabled."""
            if hasattr(self, '_m_gyro_x_mdps'):
                return self._m_gyro_x_mdps if hasattr(self, '_m_gyro_x_mdps') else None

            self._m_gyro_x_mdps = (((self.gyro_x3_mdps_raw << 16) | (self.gyro_x2_mdps_raw << 8)) | self.gyro_x1_mdps_raw)
            return self._m_gyro_x_mdps if hasattr(self, '_m_gyro_x_mdps') else None

        @property
        def t_ab1(self):
            """not set."""
            if hasattr(self, '_m_t_ab1'):
                return self._m_t_ab1 if hasattr(self, '_m_t_ab1') else None

            self._m_t_ab1 = 0.0
            return self._m_t_ab1 if hasattr(self, '_m_t_ab1') else None

        @property
        def magtl_x(self):
            """non zero if orientation enabled."""
            if hasattr(self, '_m_magtl_x'):
                return self._m_magtl_x if hasattr(self, '_m_magtl_x') else None

            self._m_magtl_x = (((self.magtl_x3_raw << 16) | (self.magtl_x2_raw << 8)) | self.magtl_x1_raw)
            return self._m_magtl_x if hasattr(self, '_m_magtl_x') else None

        @property
        def gyro_y_mdps(self):
            """non zero if orientation enabled."""
            if hasattr(self, '_m_gyro_y_mdps'):
                return self._m_gyro_y_mdps if hasattr(self, '_m_gyro_y_mdps') else None

            self._m_gyro_y_mdps = (((self.gyro_y3_mdps_raw << 16) | (self.gyro_y2_mdps_raw << 8)) | self.gyro_y1_mdps_raw)
            return self._m_gyro_y_mdps if hasattr(self, '_m_gyro_y_mdps') else None

        @property
        def mode(self):
            if hasattr(self, '_m_mode'):
                return self._m_mode if hasattr(self, '_m_mode') else None

            self._m_mode = (u"Beacon" if self.sat_mode == 2 else (u"PostLauncheDepl" if self.sat_mode == 1 else (u"Recharge" if self.sat_mode == 3 else (u"Telecom" if self.sat_mode == 4 else (u"Failsafe" if self.sat_mode == 5 else (u"Off" if self.sat_mode == 6 else (u"Sun" if self.sat_mode == 7 else u"PostLaunche")))))))
            return self._m_mode if hasattr(self, '_m_mode') else None

        @property
        def gyro_z_mdps(self):
            if hasattr(self, '_m_gyro_z_mdps'):
                return self._m_gyro_z_mdps if hasattr(self, '_m_gyro_z_mdps') else None

            self._m_gyro_z_mdps = (((self.gyro_z3_mdps_raw << 16) | (self.gyro_z2_mdps_raw << 8)) | self.gyro_z1_mdps_raw)
            return self._m_gyro_z_mdps if hasattr(self, '_m_gyro_z_mdps') else None

        @property
        def t_ab2(self):
            """not set."""
            if hasattr(self, '_m_t_ab2'):
                return self._m_t_ab2 if hasattr(self, '_m_t_ab2') else None

            self._m_t_ab2 = (self.t_ab2_raw * 0.1)
            return self._m_t_ab2 if hasattr(self, '_m_t_ab2') else None

        @property
        def mux_i5_0(self):
            if hasattr(self, '_m_mux_i5_0'):
                return self._m_mux_i5_0 if hasattr(self, '_m_mux_i5_0') else None

            self._m_mux_i5_0 = (self.mux_i5_0_raw * 0.1)
            return self._m_mux_i5_0 if hasattr(self, '_m_mux_i5_0') else None


    class IFrame(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.pid = self._io.read_u1()
            self.ax25_info = self._io.read_bytes_full()


    class SsidMask(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.ssid_mask = self._io.read_u1()

        @property
        def ssid(self):
            if hasattr(self, '_m_ssid'):
                return self._m_ssid if hasattr(self, '_m_ssid') else None

            self._m_ssid = ((self.ssid_mask & 15) >> 1)
            return self._m_ssid if hasattr(self, '_m_ssid') else None


    class Beacon2(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.device_status = self._io.read_u2le()
            self.rtc_ss = self._io.read_s4le()
            self.temp2_raw = self._io.read_s2le()
            self.temp1_raw = self._io.read_s2le()
            self.u_3_3v_digi = self._io.read_s2le()
            self.u_3_3v_rf = self._io.read_s2le()
            self.u_3_3v_rf_amp = self._io.read_s2le()

        @property
        def temp2(self):
            """value [В°C]."""
            if hasattr(self, '_m_temp2'):
                return self._m_temp2 if hasattr(self, '_m_temp2') else None

            self._m_temp2 = (self.temp2_raw * 0.1)
            return self._m_temp2 if hasattr(self, '_m_temp2') else None

        @property
        def temp1(self):
            """value [В°C]."""
            if hasattr(self, '_m_temp1'):
                return self._m_temp1 if hasattr(self, '_m_temp1') else None

            self._m_temp1 = (self.temp1_raw * 0.1)
            return self._m_temp1 if hasattr(self, '_m_temp1') else None


    class Header(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.data_type = self._io.read_u1()


    class Beacon0(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.body = (self._io.read_bytes_term(0, False, True, True)).decode(u"ASCII")


    class CallsignRaw(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self._raw__raw_callsign_ror = self._io.read_bytes(6)
            self._raw_callsign_ror = KaitaiStream.process_rotate_left(self._raw__raw_callsign_ror, 8 - (1), 1)
            _io__raw_callsign_ror = KaitaiStream(BytesIO(self._raw_callsign_ror))
            self.callsign_ror = Polyitan1.Callsign(_io__raw_callsign_ror, self, self._root)


    class Ax25Info(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.header = Polyitan1.Header(self._io, self, self._root)
            _on = self.header.data_type
            if _on == 0:
                self.data = Polyitan1.Beacon0(self._io, self, self._root)
            elif _on == 1:
                self.data = Polyitan1.Beacon1(self._io, self, self._root)
            elif _on == 2:
                self.data = Polyitan1.Beacon2(self._io, self, self._root)



